@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -97,7 +97,7 @@ sub generate {
             }
         }
         my $table = _make_table( _process( %new_args ) );
-        return wantarray ? ( $table, $js ) : $js . $table;
+        return $js . $table;
     }
 
     return _make_table( %args );
@@ -281,7 +281,7 @@ sub _args {
     $data = delete $args->{data} if exists $args->{data};
 
     my $encodes = exists $args->{encodes} ? $args->{encodes} : '';
-    $args->{_auto} = HTML::AutoTag->new( encodes => $encodes, indent => $args->{indent}, level => $args->{level} );
+    $args->{_auto} = HTML::AutoTag->new( encodes => $encodes, indent => $args->{indent}, level => $args->{level}, sorted => 1 );
 
     if ($self) {
         return ( $self, $self->{data}, $args ) if $self->{is_cached};
@@ -365,7 +365,7 @@ Procedural interface:
 
 Generate HTML tables with ease (HTML4, XHTML and HTML5). Can generate
 landscape and other rotated views, Handsontable tables, HTML calendars,
-checkboard patterns, games such as sudoku, banners and mazes, and can
+checkerboard patterns, games such as sudoku, banners and mazes, and can
 create animations of cell values and backgrounds via jQuery. Can rewrap
 existing tables from Excel, HTML, JSON, CSV and YAML files.
 
@@ -378,7 +378,7 @@ generate tables without writing a script: C<mktable>
 
   $ mktable landscape --param file=data.xls --param preserve=1 > out.html
 
-If you have L<HTML::Display> install, you can direct the output to
+If you have L<HTML::Display> installed, you can direct the output to
 your default browser:
 
   $ mktable sudoku --display
